#ifndef OSL_NCORES_H
#define OSL_NCORES_H
namespace osl {
  namespace misc {
    /**
     * Returns number of logical processors (i.e. cores).
     * Linux and Mac are supported so far.
     */
    int ncores();
  }
}
#endif /* _NCORES_H */
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
